@@ -4,7 +4,9 @@
 import datetime
 
 import agate
-import agateexcel  # noqa
+import six
+
+import agateexcel  # noqa: F401
 
 
 class TestXLSX(agate.AgateTestCase):
@@ -31,7 +33,8 @@ class TestXLSX(agate.AgateTestCase):
         self.table = agate.Table(self.rows, self.column_names, self.column_types)
 
     def test_from_xlsx_with_column_names(self):
-        table = agate.Table.from_xlsx('examples/test.xlsx', header=False, skip_lines=1, column_names=self.user_provided_column_names)
+        table = agate.Table.from_xlsx('examples/test.xlsx', header=False, skip_lines=1,
+                                      column_names=self.user_provided_column_names)
 
         self.assertColumnNames(table, self.user_provided_column_names)
         self.assertColumnTypes(table, [agate.Number, agate.Text, agate.Boolean, agate.Date, agate.DateTime])
@@ -103,10 +106,16 @@ class TestXLSX(agate.AgateTestCase):
     def test_ambiguous_date(self):
         table = agate.Table.from_xlsx('examples/test_ambiguous_date.xlsx')
 
+        # openpyxl >= 3 fixes a bug, but Python 2 is constrained to openpyxl < 3.
+        if six.PY2:
+            expected = datetime.date(1899, 12, 31)
+        else:
+            expected = datetime.date(1900, 1, 1)
+
         self.assertColumnNames(table, ['s'])
         self.assertColumnTypes(table, [agate.Date])
         self.assertRows(table, [
-            [datetime.date(1899, 12, 31)],
+            [expected],
         ])
 
     def test_empty(self):
@@ -124,3 +133,17 @@ class TestXLSX(agate.AgateTestCase):
         self.assertRows(table, [
             ['Canada', 35160000, 'value'],
         ])
+
+    def test_row_limit(self):
+        table = agate.Table.from_xlsx('examples/test.xlsx', row_limit=2)
+
+        self.assertColumnNames(table, self.column_names)
+        self.assertColumnTypes(table, [agate.Number, agate.Text, agate.Boolean, agate.Date, agate.DateTime])
+        self.assertRows(table, [r.values() for r in self.table.rows][:2])
+
+    def test_row_limit_too_high(self):
+        table = agate.Table.from_xlsx('examples/test.xlsx', row_limit=200)
+
+        self.assertColumnNames(table, self.column_names)
+        self.assertColumnTypes(table, [agate.Number, agate.Text, agate.Boolean, agate.Date, agate.DateTime])
+        self.assertRows(table, [r.values() for r in self.table.rows])
